summary refs log tree commit diff
diff options
context:
space:
mode:
authorokan <okan>2012-05-13 15:17:13 +0000
committerokan <okan>2012-05-13 15:17:13 +0000
commit57766d860642855dbbd706fef90b1560551463a7 (patch)
tree319843a7666feb96fc199bc3a5a1f68938864fe8
parentfb4936d0f7ea06554a2b11aaa2272f7ca1dd4a98 (diff)
downloadcwm-57766d860642855dbbd706fef90b1560551463a7.tar.gz
cwm-57766d860642855dbbd706fef90b1560551463a7.tar.xz
cwm-57766d860642855dbbd706fef90b1560551463a7.zip
altpersist->cycling to be more clear that this is for cycling mod
persistence; based on a diff from Alexander Polakov, in preparation for
looping through other potential cycling modifiers.
-rw-r--r--calmwm.h2
-rw-r--r--client.c6
-rw-r--r--xevents.c2
3 files changed, 5 insertions, 5 deletions
diff --git a/calmwm.h b/calmwm.h
index b69fdf8..0a3f830 100644
--- a/calmwm.h
+++ b/calmwm.h
@@ -202,7 +202,7 @@ struct screen_ctx {
 	Window			 menuwin;
 	struct color		 color[CWM_COLOR_MAX];
 	GC			 gc;
-	int			 altpersist;
+	int			 cycling;
 	int			 xmax;
 	int			 ymax;
 	struct gap		 gap;
diff --git a/xevents.c b/xevents.c
index 6c4ba71..bc45d70 100644
--- a/xevents.c
+++ b/xevents.c
@@ -331,7 +331,7 @@ xev_handle_keyrelease(XEvent *ee)
 	if (keysym != XK_Alt_L && keysym != XK_Alt_R)
 		return;
 
-	sc->altpersist = 0;
+	sc->cycling = 0;
 
 	/*
 	 * XXX - better interface... xevents should not know about
diff --git a/client.c b/client.c
index 6b28e38..713ee1d 100644
--- a/client.c
+++ b/client.c
@@ -228,7 +228,7 @@ client_setactive(struct client_ctx *cc, int fg)
 		 * If we're in the middle of alt-tabbing, don't change
 		 * the order please.
 		 */
-		if (!sc->altpersist)
+		if (!sc->cycling)
 			client_mtf(cc);
 	} else
 		client_leave(cc);
@@ -638,8 +638,8 @@ client_cycle(struct screen_ctx *sc, int flags)
 		}
 	}
 
-	/* reset when alt is released. XXX I hate this hack */
-	sc->altpersist = 1;
+	/* reset when cycling mod is released. XXX I hate this hack */
+	sc->cycling = 1;
 	client_ptrsave(oldcc);
 	client_ptrwarp(newcc);
 }